﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;
using Syncfusion.EJ2.Base;

namespace SyncfusionDropdown.Pages
{
    [IgnoreAntiforgeryToken(Order = 1001)]
    public class IndexModel : PageModel
    {
        public List<ClientFundCategoryViewModel> Categories { get; set; } = new List<ClientFundCategoryViewModel>();

        public void OnGet()
        {
            Categories = ClientFundCategoryViewModel.GetAllRecords();

        }
        public JsonResult OnPostDataSource([FromBody]DataManagerRequest dm)
        {
            var data = OrdersDetails.GetAllRecords();

            int count = data.Cast<OrdersDetails>().Count();
            return dm.RequiresCounts ? new JsonResult(new { result = data, count = count }) : new JsonResult(data);
        }

        public JsonResult OnPostInsert([FromBody]CRUDModel<OrdersDetails> value)
        {
            return new JsonResult(value.Value);
        }

        public JsonResult OnPostUpdate([FromBody]CRUDModel<OrdersDetails> value)
        {
            return new JsonResult(value.Value);
        }


        public JsonResult OnPostDelete([FromBody]CRUDModel<OrdersDetails> value)
        {
            return new JsonResult(value);
        }
    }

    public class ClientFundCategoryViewModel
    {
        public int FundCategoryID { get; set; }
        public string FundCategoryName { get; set; }
        public static List<ClientFundCategoryViewModel> categories = new List<ClientFundCategoryViewModel>();
        public ClientFundCategoryViewModel(int fundCategoryID, string fundCategoryName)
        {
            this.FundCategoryID = fundCategoryID;
            this.FundCategoryName = fundCategoryName;
        }

        public static List<ClientFundCategoryViewModel> GetAllRecords()
        {
            if (categories.Count() == 0)
            {
                categories.Add(new ClientFundCategoryViewModel(1, "Aktier Asien"));
                categories.Add(new ClientFundCategoryViewModel(2, "Branschfonder"));
                categories.Add(new ClientFundCategoryViewModel(3, "Aktier Europa"));
                categories.Add(new ClientFundCategoryViewModel(4, "Aktier Global"));
                categories.Add(new ClientFundCategoryViewModel(5, "Aktier Latinamerika"));
            }

            return categories;
        }
    }

    public class OrdersDetails
    {
        public static List<OrdersDetails> order = new List<OrdersDetails>();
        public OrdersDetails()
        {

        }
        public OrdersDetails(int portfolioFundCategoryID, string fundCategoryName, decimal weight, int fundCategoryID)
        {
            this.PortfolioFundCategoryID = portfolioFundCategoryID;
            this.FundCategoryName = fundCategoryName;
            this.FundCategoryID = fundCategoryID;
            this.Weight = weight;

        }

        public static List<OrdersDetails> GetAllRecords()
        {
            if (order.Count() == 0)
            {
                order.Add(new OrdersDetails(1, "Aktier Asien", Convert.ToDecimal(0.5), 1));
                order.Add(new OrdersDetails(2, "Branschfonder", Convert.ToDecimal(0.5), 2));
                order.Add(new OrdersDetails(3, "Aktier Europa", Convert.ToDecimal(0.7), 3));
                order.Add(new OrdersDetails(4, "Aktier Global", Convert.ToDecimal(0.3), 4));
                order.Add(new OrdersDetails(5, "Aktier Asien", Convert.ToDecimal(0.1), 1));
            }

            return order;
        }

        public int PortfolioFundCategoryID { get; set; }
        public string FundCategoryName { get; set; }
        public int FundCategoryID { get; set; }
        public decimal Weight { get; set; }

    }
}
